@@ -49,7 +49,8 @@ public:
    register_coalesce_vec4_visitor(struct brw_context *brw,
                                   struct gl_shader_program *shader_prog)
       : vec4_visitor(brw, NULL, NULL, NULL, NULL, shader_prog, NULL, NULL,
-                     false, false /* no_spills */)
+                     false, false /* no_spills */,
+                     ST_NONE, ST_NONE, ST_NONE)
    {
    }
 
@@ -88,6 +89,7 @@ protected:
    virtual vec4_instruction *emit_urb_write_opcode(bool complete)
    {
       assert(!"Not reached");
+      unreachable();
    }
 };
 
